    		Originals

    			The rules for originals is the aggregate of
    			the rules that can be found at:
    			"./Adoption_Location"

    		Laboratory :: Frontend

    			The "foam_pet" "./sveltnetics_packets" (frontent)
    			rules can be found at:
    			./Adoption_Location/frontend_licenses.csv
    			./Adoption_Location/frontend_licenses_summary.txt

    		Laboratory :: Python

    			The PyPI stuff necessary for "foam_pet" might not be
    			attached, but if they are, the rules can be found at:
    			./Laboratory/PyPI_rules_full.json
    			PyPI_rules_outline.txt

    			"ventures", "somatic", "Emergency", "biotech", "body_scan",
    			"botanist", plus "law_dictionary" licenses or rules can be found
    			at those directories.

    		(Dev Notes)

    			perhaps.. Laboratory/Frontend_Rules_Originals.HTML is written directly,
    			thus not compiled from elsewhere.

    		This can be found in "foam_pet/features/rules"